@@ -84,10 +84,10 @@ def load_credit_scoring():
     return fetch_dataset('credsco')
 
 def load_medical_costs():
-    return fetch_dataset('stroke-data')
+    return fetch_dataset('insurance')
 
 def load_stroke():
-    return fetch_dataset('insurance')
+    return fetch_dataset('stroke')
 
 def load_wind_prediction():
     return fetch_dataset('wind-dataset')
@@ -285,4 +285,4 @@ def load_sentiment(nwords, train_size=0.8):
     X_val, X_test = val_x[:test_idx], val_x[test_idx:]
     y_val, y_test = val_y[:test_idx], val_y[test_idx:]
 
-    return X_train, y_train, X_val, y_val, X_test, y_test
\ No newline at end of file
+    return X_train, y_train, X_val, y_val, X_test, y_test
